@@ -377,7 +377,7 @@ class system():
         """
         Empty = np.asarray([])
         RayTraceType = 0
-        ValToSav = [Empty, Empty, pS, pS, Empty, Empty, dC, Empty, Empty, Empty, WaveLength, Empty, Empty, Empty, Empty, j, RayTraceType]
+        ValToSav = [Empty, Empty, pS, pS, Empty, Empty, dC, Empty, Empty, Empty, WaveLength, Empty, Empty, Empty, Empty, Empty, j, RayTraceType]
         self.__CollectData(ValToSav)
 
     def __WavePrecalc(self):
